@@ -1,12 +1,12 @@
 import { urlUtil } from '@grafana/data';
 import { getTimeSrv } from 'app/features/dashboard/services/TimeSrv';
-import { DashboardModel } from 'app/features/dashboard/state';
+import { DashboardModel } from 'app/features/dashboard/state/DashboardModel';
 import { DashboardScene } from 'app/features/dashboard-scene/scene/DashboardScene';
 import { getVariablesUrlParams } from 'app/features/variables/getAllVariableValuesForUrl';
 
 import { Report, ReportDashboard, StepKey } from '../../types';
-import { getRange } from "../../utils/time";
-import { BASE_URL } from '../constants';
+import { getRange } from '../../utils/time';
+import { BASE_URL, NEW_REPORT_URL } from '../constants';
 import { defaultTimeRange, initialState } from '../state/reducers';
 
 import { collectVariables } from './variables';
@@ -91,18 +91,18 @@ export const getNewReportUrl = (dashboard: DashboardModel | DashboardScene) => {
   const uid = dashboard instanceof DashboardScene ? dashboard?.state.uid : dashboard?.uid;
   const title = dashboard instanceof DashboardScene ? dashboard?.state.title : dashboard?.title;
 
-  return `reports/new/?${variablesQuery}&${timeRangeUrl}&db-uid=${uid}&db-name=${title}`;
+  return `${NEW_REPORT_URL}/?${variablesQuery}&${timeRangeUrl}&db-uid=${uid}&db-name=${title}`;
 };
 
 export const getReportDashboardsAsUrlParam = (reportDashboards: ReportDashboard[]) => {
   return JSON.stringify(
-      reportDashboards.map((db) => {
-        const { from, to } = getRange(db.timeRange).raw || defaultTimeRange.raw;
-        return {
-          dashboard: { uid: db.dashboard?.uid },
-          timeRange: { from: from.valueOf().toString(), to: to.valueOf().toString() },
-          reportVariables: db.reportVariables,
-        };
-      })
+    reportDashboards.map((db) => {
+      const { from, to } = getRange(db.timeRange).raw || defaultTimeRange.raw;
+      return {
+        dashboard: { uid: db.dashboard?.uid },
+        timeRange: { from: from.valueOf().toString(), to: to.valueOf().toString() },
+        reportVariables: db.reportVariables,
+      };
+    })
   );
-}
+};
